<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>É necessária a autenticação para ler as informações do disco</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Run Disk Manager Need Authentication</translation>
		</message>
	</context>
</TS>